'From Squeak3.2 of 11 July 2002 [latest update: #4957] on 19 November 2002 at 9:14:25 pm'!
Magnitude subclass: #TimeStamp
	instanceVariableNames: 'date time '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Kernel-Magnitudes'!

!TimeStamp commentStamp: '<historical>' prior: 0!
An instance of this class serves as a container for a Date and a Time.  Because TimeStamp is a subclass of Magnitude, you can do lots of interesting comparisons and arithmetic operations with TimeStamps.

Structure:
	date	 --> a Date - The day on which the TimeStamp occurs.
	time --> a Time - The time at which the TimeStamp occurs.

Examples:
	TimeStamp current
	TimeStamp date: Date today time: Time now
	TimeStamp fromString: '1-10-2000 11:55:00 am'   "MM-DD-YYYY HH:MM:SS AM"
	TimeStamp current < TimeStamp noon
!


!Object methodsFor: 'MIME' stamp: 'SVP 8/17/1999 17:51'!
mimeType

	^MIMEDocument defaultContentType! !


!Color methodsFor: 'printing' stamp: 'bolot 3/17/2001 22:16'!
hex
	^(self red * 255) asInteger asCharacter hex,
	(self green * 255) asInteger asCharacter hex,
	(self blue * 255) asInteger asCharacter hex! !


!Date methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:32'!
asTimeStamp
	"Answer the receiver as a TimeStamp at midnight."

	^TimeStamp date: self time: (Time fromSeconds: 0)! !

!Date methodsFor: 'printing' stamp: 'bolot 2/22/2001 17:00'!
yyyymmdd
	"no delimiters"
	"Date today yyyymmdd"

	^ self printFormat: #(3 2 1 $- 1 1 2)! !


!MIMEDocument methodsFor: 'access' stamp: 'svp 12/16/1999 11:55'!
mimeType

	^self type! !


!MIMEDocument class methodsFor: 'initialize-release' stamp: 'bolot 1/11/2001 18:35'!
defaultMIMEdatabase
	| d |
	(d _ Dictionary new)
	at: 'html' put: 'text/html';
	at: 'htm' put: 'text/html';
	at: 'xml' put: 'text/xml';
	at: 'txt' put: 'text/plain';
	at: 'c' put: 'text/plain';
	at: 'gif' put: 'image/gif';
	at: 'jpg' put: 'image/jpeg';
	at: 'jpeg' put: 'image/jpeg';
	at: 'png' put: 'image/png';
	at: 'xbm' put: 'image/x-xbitmap';
	at: 'mid' put: 'audio/midi';
	at: 'doc' put: 'application/ms-word-document'.
	^d! !

!MIMEDocument class methodsFor: 'initialize-release' stamp: 'bolot 6/22/2001 02:28'!
extendedMIMEdatabase
	| d |
	(d _ self defaultMIMEdatabase)
	at: 'sts' put: 'application/x-squeak-source';
	at: 'pr' put: 'application/x-squeak-project';
	at: 'hqx' put: 'application/mac-binhex40';
	at: 'doc' put: 'application/msword';
	at: 'xls' put: 'application/x-excel';
	at: 'ppt' put: 'application/mspowerpoint';
	at: 'ppz' put: 'application/mspowerpoint';
	at: 'pot' put: 'application/mspowerpoint';
	at: 'pps' put: 'application/mspowerpoint';
	at: 'cpt' put: 'application/mac-compactpro';
	at: 'pdf' put: 'application/pdf';
	at: 'ps' put: 'application/postscript';
	at: 'ai' put: 'application/postscript';
	at: 'eps' put: 'application/postscript';
	at: 'rtf' put: 'text/rtf';
	at: 'bin' put: 'application/octet-stream';
	at: 'dms' put: 'application/octet-stream';
	at: 'lha' put: 'application/octet-stream';
	at: 'lzh' put: 'application/octet-stream';
	at: 'exe' put: 'application/octet-stream';
	at: 'class' put: 'application/octet-stream';
	at: 'zip' put: 'application/zip';
	at: 'gtar' put: 'application/x-gtar';
	at: 'swf' put: 'application/x-shockwave-flash';
	at: 'sit' put: 'application/x-stuffit';
	at: 'tar' put: 'application/x-tar';
	at: 'au' put: 'audio/basic';
	at: 'snd' put: 'audio/basic';
	at: 'mid' put: 'audio/midi';
	at: 'midi' put: 'audio/midi';
	at: 'mpga' put: 'audio/mpeg';
	at: 'mp2' put: 'audio/mpeg';
	at: 'mp3' put: 'audio/mpeg';
	at: 'aiff' put: 'audio/x-aiff';
	at: 'aif' put: 'audio/x-aiff';
	at: 'aifc' put: 'audio/x-aiff';
	at: 'rm' put: 'audio/x-pn-realaudio';
	at: 'ram' put: 'audio/x-pn-realaudio';
	at: 'rpm' put: 'audio/x-pn-realaudio-plugin';
	at: 'ra' put: 'audio/x-realaudio';
	at: 'wav' put: 'audio/x-wav';
	at: 'css' put: 'text/css';
	at: 'mpeg' put: 'video/mpeg';
	at: 'mpg' put: 'video/mpeg';
	at: 'mpe' put: 'video/mpeg';
	at: 'qt' put: 'video/quicktime';
	at: 'mov' put: 'video/quicktime';
	at: 'avi' put: 'video/x-msvideo';
	at: 'movie' put: 'video/x-sgi-movie'.
	^d! !

!MIMEDocument class methodsFor: 'initialize-release' stamp: 'bolot 12/19/2000 00:53'!
initialize
	"MIMEDocument initialize"

	self resetMIMEdatabase! !

!MIMEDocument class methodsFor: 'content-types' stamp: 'svp 12/16/1999 10:35'!
contentTypeGif
	^'image/gif'! !


!Morph methodsFor: 'debug and other' stamp: 'bolot 2/20/2002 12:56'!
buildDebugMenu: aHand
	"Answer a debugging menu for the receiver.  The hand argument is seemingly historical and plays no role presently"

	| aMenu aPlayer |
	aMenu _ MenuMorph new defaultTarget: self.
	aMenu addStayUpItem.
	(self hasProperty: #errorOnDraw) ifTrue:
		[aMenu add: 'start drawing again' action: #resumeAfterDrawError.
		aMenu addLine].
	(self hasProperty: #errorOnStep) ifTrue:
		[aMenu add: 'start stepping again' action: #resumeAfterStepError.
		aMenu addLine].

	aMenu add: 'inspect morph' action: #inspectInMorphic:.
	aMenu add: 'inspect owner chain' action: #inspectOwnerChain.
	Smalltalk isMorphic ifFalse:
		[aMenu add: 'inspect morph (in MVC)' action: #inspect].

	(self isKindOf: MorphicModel) ifTrue:
		[aMenu add: 'inspect model' target: self model action: #inspect].
	(aPlayer _ self player) ifNotNil:
		[aMenu add: 'inspect player' target: aPlayer action: #inspect].

     aMenu add: 'explore morph' target: self selector: #explore.

	aMenu addLine.
	aMenu add: 'viewer for Player' target: self player action: #beViewed.
	aMenu balloonTextForLastItem: 'Opens a viewer on my Player -- this is the same thing you get if you click on the cyan "View" halo handle'.
	aMenu add: 'viewer for Morph' target: self action: #viewMorphDirectly.
	aMenu balloonTextForLastItem: 'Opens a Viewer on this Morph, rather than on its Player'.
	aMenu addLine.

	aPlayer ifNotNil:
		[aPlayer class isUniClass ifTrue: [
			aMenu add: 'browse player class' target: aPlayer action: #browseHierarchy]].
	aMenu add: 'browse morph class' target: self selector: #browseHierarchy.
	aMenu addLine.

	aPlayer ifNotNil:
		[aMenu add: 'player protocol (tiles)' target: aPlayer action: #openInstanceBrowserWithTiles
			"#browseProtocolForPlayer"].
	aMenu add: 'morph protocol (text)' target: self selector: #haveFullProtocolBrowsed.
	aMenu add: 'morph protocol (tiles)' target: self selector: #openInstanceBrowserWithTiles.
	aMenu addLine.

	self addViewingItemsTo: aMenu.
	aMenu 
		add: 'make own subclass' action: #subclassMorph;
		add: 'internal name ' action: #choosePartName;
		add: 'save morph in file'  action: #saveOnFile;
		addLine;
		add: 'call #tempCommand' action: #tempCommand;
		add: 'define #tempCommand' action: #defineTempCommand;
		addLine;

		add: 'control-menu...' target: self selector: #invokeMetaMenu:;
		add: 'edit balloon help' action: #editBalloonHelpText.

	aMenu add: 'add to Comanche' action: #makeAvailableInComanche.

	^ aMenu! !


!Socket methodsFor: 'queries' stamp: 'bolot 10/21/1999 13:24'!
isOtherEndConnected
	| status |
	"Return true if this socket is connected or if the other end hasn't signalled a close yet."

	socketHandle == nil ifTrue: [^ false].
	status _ (self primSocketConnectionStatus: socketHandle).
	^(status = Connected or: [ status = ThisEndClosed ])! !

!Socket methodsFor: 'sending-receiving' stamp: 'bolot 10/22/1999 11:29'!
discardReceivedData
	"Discard any data received up until now, and return the number of bytes discarded."

	| buf totalBytesDiscarded |
	buf _ String new: 10000.
	totalBytesDiscarded _ 0.
	[self isOtherEndConnected and: [ self dataAvailable ]] whileTrue: [
		totalBytesDiscarded _
			totalBytesDiscarded + (self receiveDataInto: buf)].
	^ totalBytesDiscarded
! !

!Socket methodsFor: 'sending-receiving' stamp: 'bolot 12/18/2000 19:27'!
getData
	"Get some data"

	| buf bytesRead |
	(self waitForDataUntil: Socket standardDeadline) ifFalse: [self error: 'getData timeout'].
	buf _ String new: 4000.
	bytesRead _ self primSocket: socketHandle receiveDataInto: buf startingAt: 1 count: buf size.
	^ buf copyFrom: 1 to: (bytesRead max: 0)! !

!Socket methodsFor: 'sending-receiving' stamp: 'bolot 5/14/2001 00:59'!
getDataQuicker
	"Get some data, as getData, but with a shorter timeout"

	| buf bytesRead |
	(self waitForDataUntil: Socket quickDeadline) ifFalse: [self error: 'getData timeout'].
	buf _ String new: 4000.
	bytesRead _ self primSocket: socketHandle receiveDataInto: buf startingAt: 1 count: buf size.
	^ buf copyFrom: 1 to: (bytesRead max: 0)! !

!Socket methodsFor: 'waiting' stamp: 'bolot 12/18/2000 19:30'!
waitForDisconnectionUntil: deadline
	"Wait up until the given deadline for the the connection to be broken. Return true if it is broken by the deadline, false if not."
	"Note: The client should know the the connect is really going to be closed (e.g., because he has called 'close' to send a close request to the other end) before calling this method.
JMM 00/5/17 note that other end can close which will terminate wait"

	| extraBytes status |
	extraBytes _ 0.
	status _ self primSocketConnectionStatus: socketHandle.
	[((status = Connected) or: [status = ThisEndClosed]) and:
	 [Time millisecondClockValue < deadline]] whileTrue: [
		self dataAvailable
			ifTrue: [extraBytes _ extraBytes + self discardReceivedData].
		semaphore waitTimeoutMSecs: (deadline - Time millisecondClockValue).
		status _ self primSocketConnectionStatus: socketHandle].

	^ status ~= Connected
! !


!Socket class methodsFor: 'utilities' stamp: 'bolot 5/14/2001 00:59'!
quickDeadline
	^ self deadlineSecs: 10! !


!Stream methodsFor: 'accessing' stamp: 'SVP 8/26/1999 08:06'!
close

	"Do nothing by default"! !

!Stream methodsFor: 'accessing' stamp: 'SVP 8/12/1999 14:25'!
mimeType

	^MIMEDocument defaultContentType! !


!Time class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:36'!
fromString: aString
	"Answer a new instance for the value given by aString.

	 Time fromString: '11:55:23 am'
	"

	^self readFrom: (ReadStream on: aString)! !

!Time class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:10'!
midnight
	"Answer a new instance at midnight."

	^self fromSeconds: 0! !

!Time class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:09'!
noon
	"Answer a new instance at noon."

	^self fromSeconds: 43200! !


!TimeStamp methodsFor: 'accessing' stamp: 'ccn 10/6/2000 22:51'!
date
	"Answer the date of the receiver."

	^date! !

!TimeStamp methodsFor: 'accessing' stamp: 'ccn 10/6/2000 22:52'!
date: aDate
	"Private - set the date of the receiver."

	date := aDate! !

!TimeStamp methodsFor: 'accessing' stamp: 'ccn 10/6/2000 22:53'!
time
	"Answer the time of the receiver."

	^time! !

!TimeStamp methodsFor: 'accessing' stamp: 'ccn 10/6/2000 22:54'!
time: aTime
	"Private - set the time of the receiver."

	time := aTime! !

!TimeStamp methodsFor: 'arithmetic' stamp: 'ccn 10/7/2000 00:00'!
minusDays: anInteger
	"Answer a TimeStamp which is anInteger days before the receiver."

	^self class date: (self date addDays: anInteger negated) time: self time! !

!TimeStamp methodsFor: 'arithmetic' stamp: 'ccn 10/7/2000 00:03'!
minusSeconds: anInteger
	"Answer a TimeStamp which is anInteger number of seconds before the receiver."

	^self class fromSeconds: ((self asSeconds) - anInteger)! !

!TimeStamp methodsFor: 'arithmetic' stamp: 'ccn 10/7/2000 00:00'!
plusDays: anInteger
	"Answer a TimeStamp which is anInteger days after the receiver."

	^self class date: (self date addDays: anInteger) time: self time! !

!TimeStamp methodsFor: 'arithmetic' stamp: 'ccn 10/7/2000 00:02'!
plusSeconds: anInteger
	"Answer a TimeStamp which is anInteger number of seconds after the receiver."

	^self class fromSeconds: ((self asSeconds) + anInteger)! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:22'!
< aTimeStamp
	"Answer true if the receiver is less than aTimeStamp, otherwise answer false."

	^self date < aTimeStamp date 
		or: [self date = aTimeStamp date and: [self time < aTimeStamp time]]! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:23'!
<= aTimeStamp
	"Answer true if the receiver is less than or equal to aTimeStamp, otherwise answer false."

	^self date < aTimeStamp date
		or: [self date = aTimeStamp date and: [self time <= aTimeStamp time]]! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:41'!
= aTimeStamp
	"ccn Note:  this does not take TimeZones into account.  Some day that should be fixed..."

	^self class = aTimeStamp class
		and: [self date = aTimeStamp date
		and: [self time = aTimeStamp time]]! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:23'!
> aTimeStamp
	"Answer true if the receiver is greater than aTimeStamp, otherwise answer false."

	^self date > aTimeStamp date
		or: [self date = aTimeStamp date and: [self time > aTimeStamp time]]! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:24'!
>= aTimeStamp
	"Answer true if the receiver is greater than or equal to aTimeStamp, otherwise answer false."

	^self date > aTimeStamp date
		or: [self date = aTimeStamp date and: [self time >= aTimeStamp time]]! !

!TimeStamp methodsFor: 'comparing' stamp: 'ccn 10/6/2000 23:06'!
hash
	"Answer the Integer hash value for the receiver."

	^self date hash bitXor: self time hash! !

!TimeStamp methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:04'!
asDate
	"Answer the receiver as an instance of Date."

	^self date! !

!TimeStamp methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:25'!
asSeconds
	"Return the number of seconds in the receiver."

	^(self date asSeconds + self time asSeconds)! !

!TimeStamp methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:04'!
asTime
	"Answer the receiver as an instance of Time."

	^self time! !

!TimeStamp methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:33'!
asTimeStamp
	"Answer the receiver as an instance of TimeStamp."

	^self! !

!TimeStamp methodsFor: 'converting' stamp: 'ccn 10/6/2000 23:34'!
dateAndTime
	"Answer a two element Array containing the receiver's date and time."

	^Array with: self date with: self time! !

!TimeStamp methodsFor: 'printing' stamp: 'ccn 10/6/2000 23:51'!
printOn: aStream
	"Print receiver's date and time on aStream."

	| dateString timeString |
	dateString _ (self date isNil)
		ifTrue: ['no date']
		ifFalse: [self date printString].
	timeString _ (self time isNil)
		ifTrue: ['no time']
		ifFalse: [self time printString].
	(self date isNil and: [self time isNil])
		ifTrue:
			[super printOn: aStream.
			aStream nextPutAll: ' '].
	aStream 
		nextPutAll: dateString;
		nextPutAll: ', ';
		nextPutAll: timeString! !


!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/6/2000 22:59'!
current
	"Answer the current date and time as a TimeStamp."

	| array |
	array _ Time dateAndTimeNow.
	^self date: array first time: array last! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/6/2000 23:00'!
date: aDate time: aTime
	"Answer a new instance based on the given date and time."

	^self
		new date: aDate;
		time: aTime;
		yourself! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:07'!
fromSeconds: anInteger
	"Answer a new instance based on the given number of seconds."

	| date |
	date _ Date fromSeconds: anInteger.
	^self date: date time: (Time fromSeconds: (anInteger - date asSeconds))! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:36'!
fromString: aString
	"Answer a new instance for the value given by aString.

	 TimeStamp fromString: '1-10-2000 11:55:00 am'. 
	"

	| stream |
	stream := ReadStream on: aString withBlanksTrimmed.
	^self 
		date: (Date fromString: (stream upTo: $ )) 
		time: (Time fromString: (stream upTo: nil))! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:18'!
midnight
	"Answer a new instance that represents today at midnight."

	^self midnightOn: Date today! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:19'!
midnightOn: aDate
	"Answer a new instance that represents aDate at midnight."

	^self date: aDate time: Time midnight! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:16'!
noon
	"Answer a new instance that represents today at noon."

	^self noonOn: Date today! !

!TimeStamp class methodsFor: 'instance creation' stamp: 'ccn 10/7/2000 00:16'!
noonOn: aDate
	"Answer a new instance that represents aDate at noon."

	^self date: aDate time: Time noon! !


!WriteStream methodsFor: 'as yet unclassified' stamp: 'SVP 8/24/1999 15:49'!
mimeType

	^'text/html'! !


!StandardFileStream methodsFor: 'access' stamp: 'SVP 8/24/1999 15:47'!
mimeType

	^MIMEDocument guessTypeFromName: self name.
! !


!WriteStream reorganize!
('accessing' contents next nextPut: nextPutAll: size)
('positioning' position: reset resetToStart setToEnd)
('character writing' cr crtab crtab: ensureASpace ensureNoSpace nextPutKeyword:withArg: peekLast space tab tab:)
('fileIn/Out' nextChunkPut: nextChunkPutWithStyle: timeStamp)
('printing' store:)
('private' braceArray braceArray: on: on:from:to: pastEndPut: with: withAttribute:do: withAttributes:do:)
('file open/close' flush)
('*kom-processing' asHttpResponseTo:)
('as yet unclassified' mimeType)
!


!TextMorph reorganize!
('initialization' beAllFont: configureForKids copy defaultColor initialize releaseCachedState setTextStyle: string:fontName:size: string:fontName:size:wrap:)
('accessing' asText autoFit: backgroundColor backgroundColor: borderWidth: contents contents: contents:wrappedTo: contentsAsIs: contentsWrapped: crAction crAction: currentDataValue editor fillStyle fillStyle: fontName:size: getCharacters getFirstCharacter hasTranslucentColor isAutoFit isTextMorph isWrapped margins margins: newContents: setCharacters: setFirstCharacter: setNumericValue: text textColor textColor: textStyle userString wrapFlag:)
('alignment' centered justified leftFlush rightFlush)
('drawing' debugDrawLineRectsOn: drawNullTextOn: drawOn:)
('editing' acceptContents cancelEdits chooseAlignment chooseEmphasis chooseEmphasisOrAlignment chooseFont chooseStyle clearTypeIn enterClickableRegion: handleEdit: handleInteraction:fromEvent: handleKeystroke: handleMouseMove: handlesKeyboard: handlesMouseDown: hasFocus hasUnacceptedEdits: keyStroke: keyboardFocusChange: mouseDown: mouseMove: mouseUp: passKeyboardFocusTo: xeqLinkText:withParameter:)
('printing' fullPrintOn:)
('geometry' areasRemainingToFill: bounds container containsPoint: defaultLineHeight extent: goBehind layoutChanged minimumExtent privateMoveBy: textBounds)
('menu' addCustomMenuItems:hand: autoFitOnOff autoFitString changeMargins: changeTextColor followCurve reverseCurveDirection setCurveBaseline: shiftedYellowButtonActivity wrapOnOff wrapString yellowButtonActivity)
('linked frames' addPredecessor: addSuccessor: firstCharacterIndex firstInChain isLinkedTo: lastCharacterIndex predecessor recomposeChain startingIndex successor withSuccessorsDo:)
('private' adjustLineIndicesBy: clippingRectangle composeToBounds compositionRectangle delete fit installEditor installEditorToReplace: loadCachedState paragraph paragraphClass predecessor:successor: predecessorChanged releaseEditor releaseParagraph releaseParagraphReally selectionChanged setDefaultContentsIfNil setPredecessor: setSuccessor: text:textStyle: text:textStyle:wrap:color:predecessor:successor: updateFromParagraph updateReferencesUsing: wouldAcceptKeyboardFocusUponTab)
('object fileIn' convertToCurrentVersion:refStream:)
('containment' fillingOnOff occlusionsOnOff ownerChanged privateOwner: recognizerArena setContainer:)
('anchors' acceptDroppingMorph:event: addMorphFront:fromWorldPosition: adjustTextAnchor: anchorMorph:at:type: privateRemoveMorph:)
('copying' veryDeepFixupWith: veryDeepInner:)
('scripting access' getAllButFirstCharacter getNumericValue setAllButFirstCharacter:)
('card & stack' basicType couldHoldSeparateDataForEachInstance newContents:fromCard: setNewContentsFrom: variableDocks)
('genie-processing' defaultGestureDictionaryOrName)
('genie-dispatching' gestureHandler handleGesture: lastGesture lastGesture: setAlignment:)
('*kom-processing' asHttpResponseTo:)
!


!Morph reorganize!
('initialization' basicInitialize currentVocabulary inATwoWayScrollPane initialExtent initialize intoWorld: openCenteredInWorld openInHand openInMVC openInWindow openInWindowLabeled: openInWindowLabeled:inWorld: openInWorld openInWorld: outOfWorld: resourceJustLoaded standardPalette)
('classification' demandsBoolean isAlignmentMorph isBalloonHelp isFlapOrTab isFlapTab isFlashMorph isFlexMorph isHandMorph isModalShell isMorph isMorphicModel isPlayfieldLike isRenderer isStandardViewer isSyntaxMorph isTextMorph isWorldMorph isWorldOrHandMorph)
('accessing' actorState actorState: actorStateOrNil adoptPaneColor: asMorph balloonText balloonTextSelector balloonTextSelector: beFlap: beSticky beUnsticky borderColor borderColor: borderStyle borderStyle: borderStyleForSymbol: borderWidth borderWidth: borderWidthForRounding color color: colorForInsets couldHaveRoundedCorners eventHandler eventHandler: forwardDirection hasTranslucentColor highlight highlightColor highlightColor: highlightOnlySubmorph: insetColor isFlap isLocked isShared isSticky lock lock: methodCommentAsBalloonHelp modelOrNil player player: raisedColor regularColor regularColor: rememberedColor rememberedColor: resistsRemoval resistsRemoval: scaleFactor setBorderStyle: sqkPage sticky: toggleLocked toggleResistsRemoval toggleStickiness unHighlight unlock unlockContents url userString wantsToBeCachedByHand)
('access properties' hasProperty: removeProperty: setProperty:toValue: valueOfProperty: valueOfProperty:ifAbsent: valueOfProperty:ifAbsentPut: valueOfProperty:ifPresentDo:)
('copying' copy deepCopy duplicate fullCopy updateReferencesUsing: usableSiblingInstance veryDeepCopyWith: veryDeepFixupWith: veryDeepInner:)
('structure' activeHand allOwners allOwnersDo: firstOwnerSuchThat: hasOwner: isInWorld morphPreceding: nearestOwnerThat: orOwnerSuchThat: outermostMorphThat: outermostWorldMorph owner ownerThatIsA: ownerThatIsA:orA: pasteUpMorph pasteUpMorphHandlingTabAmongFields presenter primaryHand renderedMorph root rootAt: topPasteUp topRendererOrSelf withAllOwners withAllOwnersDo: world)
('submorphs-accessing' allKnownNames allMorphs allMorphsDo: allNonSubmorphMorphs allSubmorphNamesDo: findA: findDeepSubmorphThat:ifAbsent: findDeeplyA: findSubmorphBinary: firstSubmorph hasSubmorphWithProperty: hasSubmorphs indexOfMorphAbove: lastSubmorph morphsAt: morphsAt:behind:unlocked: morphsAt:unlocked: morphsAt:unlocked:do: morphsInFrontOf:overlapping:do: morphsInFrontOverlapping: morphsInFrontOverlapping:do: rootMorphsAt: rootMorphsAtGlobal: shuffleSubmorphs submorphAfter submorphBefore submorphCount submorphNamed: submorphNamed:ifNone: submorphOfClass: submorphThat:ifNone: submorphWithProperty: submorphs submorphsBehind:do: submorphsDo: submorphsInFrontOf:do: submorphsReverseDo: submorphsSatisfying:)
('submorphs-add/remove' abandon actWhen actWhen: addAllMorphs: addAllMorphs:after: addMorph: addMorph:after: addMorph:asElementNumber: addMorph:behind: addMorph:fullFrame: addMorph:inFrontOf: addMorphBack: addMorphCentered: addMorphFront: addMorphFront:fromWorldPosition: addMorphFrontFromWorldPosition: addMorphNearBack: comeToFront copyWithoutSubmorph: delete deleteSubmorphsWithProperty: dismissViaHalo goBehind privateDelete removeAllMorphs removeAllMorphsIn: replaceSubmorph:by: submorphIndexOf:)
('drawing' areasRemainingToFill: boundingBoxOfSubmorphs boundsWithinCorners changeClipSubmorphs clipLayoutCells clipLayoutCells: clipSubmorphs clipSubmorphs: clippingBounds doesOwnRotation drawDropHighlightOn: drawDropShadowOn: drawErrorOn: drawMouseDownHighlightOn: drawOn: drawOnCanvas: drawPostscriptOn: drawRolloverBorderOn: drawSubmorphsOn: expandFullBoundsForDropShadow: expandFullBoundsForRolloverBorder: flash fullDrawOn: fullDrawPostscriptOn: hasClipSubmorphsString hide highlightForMouseDown highlightForMouseDown: highlightedForMouseDown imageForm imageForm:forRectangle: imageFormDepth: imageFormForRectangle: imageFormWithout:andStopThere: refreshWorld shadowForm show visible visible:)
('geometry' align:with: bottom bottom: bottomLeft bottomLeft: bottomRight bottomRight: bounds bounds: bounds:from: bounds:in: boundsIn: boundsInWorld center center: extent extent: fullBoundsInWorld globalPointToLocal: gridPoint: griddedPoint: height height: innerBounds left left: localPointToGlobal: minimumExtent minimumExtent: nextOwnerPage outerBounds point:from: point:in: pointFromWorld: pointInWorld: position position: positionInWorld positionSubmorphs previousOwnerPage right right: screenLocation screenRectangle setConstrainedPosition:hangOut: shiftSubmorphsBy: shiftSubmorphsOtherThan:by: top top: topLeft topLeft: topRight topRight: transformedBy: width width: worldBounds worldBoundsForHalo)
('rotate scale and flex' addFlexShell addFlexShellIfNecessary keepsTransform newTransformationMorph rotationDegrees)
('geometry testing' containsPoint: fullContainsPoint: obtrudesBeyondContainer)
('geometry eToy' addTransparentSpacerOfSize: beTransparent cartesianBoundsTopLeft cartesianXY: color:sees: colorUnder degreesOfFlex forwardDirection: getIndexInOwner goHome heading heading: move:toPosition: referencePosition referencePosition: referencePositionInWorld referencePositionInWorld: rotationCenter rotationCenter: setDirectionFrom: setIndexInOwner: touchesColor: transparentSpacerOfSize: wrap x x: x:y: y y:)
('thumbnail' demandsThumbnailing morphRepresented permitsThumbnailing readoutForField: representativeNoTallerThan:norWiderThan:thumbnailHeight: updateThumbnailUrl updateThumbnailUrlInBook:)
('dropping/grabbing' aboutToBeGrabbedBy: asDraggableMorph disableDragNDrop dragEnabled dragEnabled: dragNDropEnabled dragSelectionColor dropEnabled dropEnabled: dropHighlightColor dropSuccessColor enableDrag: enableDragNDrop enableDragNDrop: enableDrop: formerOwner formerOwner: formerPosition formerPosition: grabTransform highlightForDrop highlightForDrop: highlightedForDrop justDroppedInto:event: justGrabbedFrom: nameForUndoWording rejectDropMorphEvent: repelsMorph:event: resetHighlightForDrop separateDragAndDrop slideBackToFormerSituation: slideToTrash: startDrag:with: toggleDragNDrop transportedMorph undoGrabCommand vanishAfterSlidingTo:event: wantsDroppedMorph:event: wantsToBeDroppedInto: wantsToBeOpenedInWorld willingToBeDiscarded)
('event handling' click click: cursorPoint doubleClick: doubleClickTimeout: dropFiles: firstClickTimedOut: handlesKeyboard: handlesMouseDown: handlesMouseOver: handlesMouseOverDragging: handlesMouseStillDown: hasFocus keyDown: keyStroke: keyUp: keyboardFocusChange: mouseDown: mouseEnter: mouseEnterDragging: mouseLeave: mouseLeaveDragging: mouseMove: mouseStillDown: mouseStillDownThreshold mouseUp: on:send:to: on:send:to:withValue: removeLink: restoreSuspendedEventHandler startDrag: suspendEventHandler transformFrom: transformFromOutermostWorld transformFromWorld wantsDropFiles: wantsEveryMouseMove wantsKeyboardFocusFor: wouldAcceptKeyboardFocus wouldAcceptKeyboardFocusUponTab)
('pen' choosePenColor: choosePenSize getPenColor getPenDown getPenSize liftPen lowerPen penColor: penUpWhile: trailMorph)
('naming' choosePartName defaultNameStemForInstances downshiftedNameOfObjectRepresented externalName innocuousName knownName name: nameForFindWindowFeature nameInModel nameOfObjectRepresented renameTo: setNamePropertyTo: setNameTo: specialNameInModel tryToRenameTo: updateAllScriptingElements)
('stepping and presenter' arrangeToStartStepping arrangeToStartSteppingIn: isStepping isSteppingSelector: start startStepping startStepping:at:arguments:stepTime: startSteppingIn: startSteppingSelector: step stepAt: stepTime stop stopStepping stopSteppingSelector: stopSteppingSelfAndSubmorphs wantsSteps)
('menus' absorbStateFromRenderer: adMiscExtrasTo: addAddHandMenuItemsForHalo:hand: addCopyItemsTo: addCustomHaloMenuItems:hand: addCustomMenuItems:hand: addExportMenuItems:hand: addFillStyleMenuItems:hand: addHaloActionsTo: addPaintingItemsTo:hand: addPlayerItemsTo: addStackItemsTo: addStandardHaloMenuItemsTo:hand: addTitleForHaloMenu: addToggleItemsToHaloMenu: adhereToEdge adhereToEdge: adjustedCenter adjustedCenter: allMenuWordings changeColor changeDirectionHandles changeDragAndDrop chooseNewGraphic chooseNewGraphicCoexisting: chooseNewGraphicFromHalo collapse dismissButton doMenuItem: exportAsBMP exportAsGIF exportAsJPEG hasDirectionHandlesString hasDragAndDropEnabledString helpButton inspectInMorphic inspectInMorphic: lockUnlockMorph lockedString makeNascentScript maybeAddCollapseItemTo: menuItemAfter: menuItemBefore: presentHelp printPSToFile printPSToFileNamed: putOnBackground putOnForeground resetForwardDirection resistsRemovalString setRotationCenter setRotationCenterFrom: setToAdhereToEdge: snapToEdgeIfAppropriate stickinessString transferStateToRenderer: uncollapseSketch)
('halos and balloon help' addHalo addHalo: addHalo:from: addHandlesTo:box: addMagicHaloFor: addOptionalHandlesTo:box: addSimpleHandlesTo:box: addWorldHandlesTo:box: balloonColor balloonColor: balloonFont balloonFont: balloonHelpAligner balloonHelpDelayTime balloonHelpTextForHandle: boundsForBalloon comeToFrontAndAddHalo defaultBalloonColor defaultBalloonFont defersHaloOnClickTo: deleteBalloon editBalloonHelpContent: editBalloonHelpText halo haloClass haloDelayTime hasHalo hasHalo: isLikelyRecipientForMouseOverHalos mouseDownOnHelpHandle: noHelpString okayToAddDismissHandle okayToAddGrabHandle okayToBrownDragEasily okayToExtractEasily okayToResizeEasily okayToRotateEasily removeHalo setBalloonText: setBalloonText:maxLineLength: setCenteredBalloonText: showBalloon: showBalloon:hand: transferHalo:from: wantsBalloon wantsDirectionHandles wantsDirectionHandles: wantsHalo wantsHaloFor: wantsHaloFromClick wantsHaloHandleWithSelector:inHalo: wantsScriptorHaloHandle)
('change reporting' addedOrRemovedSubmorph: changed colorChangedForSubmorph: invalidRect: invalidRect:from: ownerChanged userSelectedColor:)
('player' assureExternalName assuredCardPlayer assuredPlayer currentDataValue newPlayerInstance okayToDuplicate shouldRememberCostumes showPlayerMenu variableDocks)
('player commands' beep beep: jumpTo: makeFenceSound set:)
('player viewer' openViewerForArgument updateLiteralLabel)
('scripting' asEmptyPermanentScriptor bringTileScriptingElementsUpToDate bringUpToDate categoriesForViewer instantiatedUserScriptsDo: isTileLike isTileScriptingElement jettisonScripts makeAllTilesColored makeAllTilesGreen restoreTypeColor scriptEditorFor: scriptPerformer selectorsForViewer tearOffTile triggerScript: useUniformTileColor viewAfreshIn:showingScript:at:)
('e-toy support' adaptToWorld: adoptVocabulary: allMorphsAndBookPagesInto: appearsToBeSameCostumeAs: asNumber: asWearableCostume asWearableCostumeOfExtent: automaticViewing changeAllBorderColorsFrom:to: configureForKids containingWindow copyCostumeStateFrom: creationStamp currentPlayerDo: cursor cursor: defaultFloatPrecisionFor: defaultValueOrNil defaultVariableName definePath deletePath embedInWindow embeddedInMorphicWindowLabeled: enclosingEditor enforceTileColorPolicy fenceEnabled followPath getNumericValue gridFormOrigin:grid:background:line: isAViewer isCandidateForAutomaticViewing isTileEditor listViewLineForFieldList: makeGraphPaper makeGraphPaperGrid:background:line: mustBeBackmost noteNegotiatedName:for: objectViewed referencePlayfield rotationStyle rotationStyle: setAsActionInButtonProperties: setNaturalLanguageTo: setNumericValue: setStandardTexture slotSpecifications succeededInRevealing: textureParameters topEditor unlockOneSubpart updateCachedThumbnail wantsRecolorHandle wrappedInWindow: wrappedInWindowWithTitle:)
('button' doButtonAction fire firedMouseUpCode)
('parts bin' inPartsBin initializeToStandAlone isPartsBin isPartsDonor isPartsDonor: markAsPartsDonor partRepresented residesInPartsBin)
('printing' asEPS asPostscript asPostscriptPrintJob clipPostscript colorString: constructorString defaultLabelForInspector fullPrintOn: initString morphReport morphReportFor: morphReportFor:on:indent: pagesHandledAutomatically printConstructorOn:indent: printConstructorOn:indent:nodeDict: printOn: printSpecs printSpecs: printStructureOn:indent: structureString textToPaste)
('property extension' assureExtension extension otherProperties resetExtension)
('caching' fullLoadCachedState fullReleaseCachedState loadCachedState releaseCachedState)
('debug and other' addDebuggingItemsTo:hand: addMouseActionIndicatorsWidth:color: addMouseUpAction addMouseUpActionWith: addViewingItemsTo: allStringsAfter: altSpecialCursor0 altSpecialCursor1 altSpecialCursor2 altSpecialCursor3 altSpecialCursor3: buildDebugMenu: defineTempCommand deleteAnyMouseActionIndicators handMeTilesToFire inspectArgumentsPlayerInMorphic: inspectOwnerChain installModelIn: mouseUpCodeOrNil ownerChain programmedMouseDown:for: programmedMouseEnter:for: programmedMouseLeave:for: programmedMouseUp:for: programmedMouseUp:for:with: removeMouseUpAction reportableSize resumeAfterDrawError resumeAfterStepError tempCommand viewMorphDirectly)
('private' moveWithPenDownBy: moveWithPenDownByRAA: myEvents myEvents: privateAddMorph:atIndex: privateBounds: privateColor: privateDeleteWithAbsolutelyNoSideEffects privateFullBounds: privateFullMoveBy: privateMoveBy: privateOwner: privateRemoveMorph: privateRemoveMorphWithAbsolutelyNoSideEffects: privateSubmorphs privateSubmorphs:)
('fileIn/out' attachToResource objectForDataStream: prepareToBeSaved reserveUrl: saveAsResource saveDocPane saveOnFile saveOnURL saveOnURL: saveOnURLbasic storeDataOn: updateAllFromResources updateFromResource)
('object fileIn' convertAugust1998:using: convertNovember2000DropShadow:using: convertToCurrentVersion:refStream:)
('visual properties' canHaveFillStyles cornerStyle defaultColor fillStyle fillStyle: fillWithRamp:oriented: useBitmapFill useDefaultFill useGradientFill useSolidFill)
('texture support' asTexture installAsWonderlandTextureOn: isValidWonderlandTexture isValidWonderlandTexture: mapPrimitiveVertex: wonderlandTexture wonderlandTexture:)
('card in a stack' abstractAModel beAStackBackground containsCard: couldHoldSeparateDataForEachInstance currentDataInstance explainDesignations goToNextCardInStack goToPreviousCardInStack holdsSeparateDataForEachInstance insertAsStackBackground insertCard installAsCurrent: isStackBackground makeHoldSeparateDataForEachInstance newCard reassessBackgroundShape relaxGripOnVariableNames reshapeBackground setAsDefaultValueForNewCard showBackgroundObjects showDesignationsOfObjects showForegroundObjects stack stackDo: stopHoldingSeparateDataForEachInstance tabHitWithEvent: wrapWithAStack)
('WiW support' addMorphInFrontOfLayer: addMorphInLayer: eToyRejectDropMorph:event: morphicLayerNumber morphicLayerNumberWithin: randomBoundsFor: shouldGetStepsFrom:)
('rounding' cornerStyle: roundedCorners roundedCornersString toggleCornerRounding wantsRoundedCorners)
('undo' commandHistory undoMove:redo:owner:bounds:predecessor:)
('events-alarms' addAlarm:after: addAlarm:at: addAlarm:with:after: addAlarm:with:at: addAlarm:with:with:after: addAlarm:with:with:at: addAlarm:withArguments:after: addAlarm:withArguments:at: alarmScheduler removeAlarm: removeAlarm:at:)
('events-processing' containsPoint:event: defaultEventDispatcher handleDropFiles: handleDropMorph: handleEvent: handleFocusEvent: handleKeyDown: handleKeyUp: handleKeystroke: handleListenEvent: handleMouseDown: handleMouseEnter: handleMouseLeave: handleMouseMove: handleMouseOver: handleMouseStillDown: handleMouseUp: handleUnknownEvent: handlerForMouseDown: mouseDownPriority processEvent: processEvent:using: rejectDropEvent: rejectsEvent: transformedFrom:)
('meta-actions' addEmbeddingMenuItemsTo:hand: applyStatusToAllSiblings: beThisWorldsModel blueButtonDown: blueButtonUp: bringAllSiblingsToMe: buildHandleMenu: buildMetaMenu: changeColorTarget:selector:originalColor:hand: copyToPasteBuffer: dismissMorph: duplicateMorph: embedInto: grabMorph: handlerForBlueButtonDown: handlerForMetaMenu: inspectAt:event: invokeMetaMenu: invokeMetaMenuAt:event: makeMultipleSiblings: makeNewPlayerInstance: makeSiblings: makeSiblingsLookLikeMe: maybeDuplicateMorph maybeDuplicateMorph: openAButtonPropertySheet openAPropertySheet openATextPropertySheet potentialEmbeddingTargets resizeFromMenu resizeMorph: saveAsPrototype showActions showHiders subclassMorph)
('testing' canDrawAtHigherResolution canDrawBorder: completeModificationHash isFlexed modificationHash shouldDropOnMouseUp)
('drop shadows' addDropShadow addDropShadowMenuItems:hand: changeShadowColor hasDropShadow hasDropShadow: hasDropShadowString hasRolloverBorder hasRolloverBorder: removeDropShadow setShadowOffset: shadowColor shadowColor: shadowOffset shadowOffset: shadowPoint: toggleDropShadow)
('layout' acceptDroppingMorph:event: adjustLayoutBounds doLayoutIn: fullBounds layoutBounds layoutBounds: layoutChanged layoutInBounds: layoutProportionallyIn: minExtent minHeight minHeight: minWidth minWidth: privateFullBounds submorphBounds)
('layout-menu' addCellLayoutMenuItems:hand: addLayoutMenuItems:hand: addTableLayoutMenuItems:hand: changeCellInset: changeClipLayoutCells changeDisableTableLayout changeLayoutInset: changeListDirection: changeMaxCellSize: changeMinCellSize: changeNoLayout changeProportionalLayout changeReverseCells changeRubberBandCells changeTableLayout hasClipLayoutCellsString hasDisableTableLayoutString hasNoLayoutString hasProportionalLayoutString hasReverseCellsString hasRubberBandCellsString hasTableLayoutString layoutMenuPropertyString:from:)
('layout-properties' assureLayoutProperties assureTableProperties cellInset cellInset: cellPositioning cellPositioning: cellPositioningString: cellSpacing cellSpacing: cellSpacingString: disableTableLayout disableTableLayout: hResizing hResizing: hResizingString: layoutFrame layoutFrame: layoutInset layoutInset: layoutPolicy layoutPolicy: layoutProperties layoutProperties: listCentering listCentering: listCenteringString: listDirection listDirection: listDirectionString: listSpacing listSpacing: listSpacingString: maxCellSize maxCellSize: minCellSize minCellSize: reverseTableCells reverseTableCells: rubberBandCells rubberBandCells: spaceFillWeight spaceFillWeight: vResizeToFit: vResizing vResizing: vResizingString: wrapCentering wrapCentering: wrapCenteringString: wrapDirection wrapDirection: wrapDirectionString:)
('piano rolls' addMorphsTo:pianoRoll:eventTime:betweenTime:and: encounteredAtTime:inScorePlayer:atIndex:inEventTrack:secsPerTick: justDroppedIntoPianoRoll:event: pauseFrom: resetFrom: resumeFrom: triggerActionFromPianoRoll)
('genie-menu' addGenieMenuItems:hand: changeGestureDictionary hasNotExportedGestureDictionary hasReferencedGestureDictionary inspectGestureDictionary makeOwnCopyOfGestureDictionary makeOwnSubGestureDictionary)
('genie-dispatching' blueButtonClickHand:shift: gesture: gestureCode: gestureCommand: gestureKeystrokes: gestureMouseEvent: gestureStrokes: handleGesture: isGestureUndoable: isSpecialCharacterUndoable: modifyGesture:by: undoGesture:)
('genie-processing' allowsGestureEscape allowsGesturePreprocessing allowsGestureStart: defaultGestureDictionaryOrName disableGestures gestureDictionary gestureDictionaryOrName gestureDictionaryOrName: gestureHandler gestureStart: handlesGestureStart: onGestureSend:to:)
('button properties' buttonProperties buttonProperties: ensuredButtonProperties hasButtonProperties)
('other events' menuButtonMouseEnter: menuButtonMouseLeave:)
('miscellaneous' setExtentFromHalo:)
('other' removeAllButFirstSubmorph)
('messenger' affiliatedSelector)
('menu' addBorderStyleMenuItems:hand:)
('text-anchor' addTextAnchorMenuItems:hand: changeDocumentAnchor changeInlineAnchor changeParagraphAnchor hasDocumentAnchorString hasInlineAnchorString hasParagraphAnchorString relativeTextAnchorPosition relativeTextAnchorPosition: textAnchorType textAnchorType:)
('*kom-processing' asHttpResponseTo:)
!

MIMEDocument initialize!

!Form reorganize!
('initialize-release' allocateForm: finish flush fromDisplay: shutDown)
('accessing' bits bits: center defaultCanvasClass depth depth: displayScreen extent form getCanvas hasBeenModified hasBeenModified: height nativeDepth offset offset: size width)
('copying' as8BitColorForm asFormOfDepth: contentsOfArea: contentsOfArea:into: copy: copy:from:in:rule: copy:from:to:rule: deepCopy veryDeepCopyWith:)
('displaying' colormapIfNeededForDepth: copyBits:at:translucent: copyBits:from:at:clippingBox:rule:fillColor: copyBits:from:at:clippingBox:rule:fillColor:map: copyBits:from:at:colorMap: displayInterpolatedIn:on: displayInterpolatedOn: displayOn:at:clippingBox:rule:fillColor: displayOn:transformation:clippingBox:align:with:rule:fillColor: displayOnPort:at: displayResourceFormOn: displayScaledOn: drawLine:from:to:clippingBox:rule:fillColor: graphicForViewerTab maskingMap paintBits:at:translucent: setAsBackground)
('display box access' boundingBox computeBoundingBox)
('filling' anyShapeFill bitPatternForDepth: colorAt: colorAt:put: convexShapeFill: eraseShape: fill:rule:fillColor: fillFromXColorBlock: fillFromXYColorBlock: fillFromYColorBlock: findShapeAroundSeedBlock: floodFill2:at: floodFill:at: floodFill:at:tolerance: floodFillMapFrom:to:mappingColorsWithin:to: isAllWhite isTransparentAt: makeBWForm: pixelValueAt: pixelValueAt:put: shapeFill:interiorPoint: shapeFill:seedBlock:)
('bordering' border:width:rule:fillColor: borderFormOfWidth:sharpCorners: borderWidth: borderWidth:color: borderWidth:fillColor: shapeBorder:width: shapeBorder:width:interiorPoint:sharpCorners:internal:)
('scaling, rotation' flipBy:centerAt: magnify:by: magnify:by:smoothing: magnifyBy: rotateBy: rotateBy:centerAt: rotateBy:magnify:smoothing: rotateBy:smoothing: scaledToSize: shrink:by:)
('editing' bitEdit bitEditAt:scale: edit morphEdit)
('image manipulation' cgForPixelValue:orNot: copyWithColorsReducedTo: dominantColor innerPixelRectFor:orNot: orderedDither32To16 pixelCompare:with:at: primCountBits rectangleEnclosingPixelsNotOfColor: reducedPaletteOfSize: replaceColor:withColor: smear:distance: tallyPixelValues tallyPixelValuesInRect:into: trimBordersOfColor: xTallyPixelValue:orNot: yTallyPixelValue:orNot:)
('fileIn/Out' comeFullyUpOnReload: encodeForRemoteCanvas hibernate objectForDataStream: printOn: readFrom: readFromOldFormat: replaceByResource: store15To24HexBitsOn: store32To24HexBitsOn: storeBits:to:on: storeBitsOn:base: storeHexBitsOn: storeOn: storeOn:base: unhibernate writeBMPfileNamed: writeJPEGfileNamed: writeJPEGfileNamed:progressive: writeOn: writeOnMovie: writeUncompressedOn:)
('private' hackBits: initFromArray: privateFloodFillValue: setExtent:depth: setExtent:depth:bits: setResourceBits:)
('other' asCursorForm asGrayScale bitsSize colorReduced colorsUsed formForColorCount: mapColor:to: mapColors:to: newColorMap primPrintHScale:vScale:landscape:)
('transitions' fadeImage:at:indexAndMaskDo: fadeImageCoarse:at: fadeImageFine:at: fadeImageHor:at: fadeImageHorFine:at: fadeImageSquares:at: fadeImageVert:at: pageImage:at:corner: pageWarp:at:forward: slideImage:at:delta: wipeImage:at:clippingBox:rectForIndex: wipeImage:at:delta: wipeImage:at:delta:clippingBox: zoomIn:orOutTo:at:vanishingPoint: zoomInTo:at: zoomOutTo:at:)
('as yet unclassified' addDeltasFrom: baldMountainWorkspace deltaFrom: deltaFrom:at: relativeTextAnchorPosition)
('postscript generation' bitsPerComponent bytesPerRow decodeArray encodePostscriptOn: numComponents paddedWidth printPostscript:operator: rowPadding setColorspaceOn:)
('converting' asMorph asTexture)
('Demo' blankCopyOf:scaledBy:)
('color mapping' balancedPatternFor: bitPatternFor: colormapFromARGB colormapIfNeededFor: colormapToARGB pixelValueFor: pixelWordFor: rgbaBitMasks)
('testing' appearsToBeSameCostumeAs: hasNonStandardPalette isBigEndian isBltAccelerated:for: isColorForm isDisplayScreen isExternalForm isFillAccelerated:for: isForm isLittleEndian isStatic shouldPreserveContents)
('resources' readNativeResourceFrom: readResourceFrom: resourceTag storeResourceOn:)
('*kom-processing' asHtmlElementIn: asHttpResponseTo: asWebImage)
!


!Object reorganize!
('accessing' addInstanceVarNamed:withValue: at: at:modify: at:put: basicAt: basicAt:put: basicSize bindWithTemp: doIfNotNil: ifNotNilDo: in: presenter readFromString: size yourself)
('associating' ->)
('binding' bindingOf:)
('casing' caseOf: caseOf:otherwise:)
('class membership' class inheritsFromAnyIn: isKindOf: isKindOf:orOf: isMemberOf: respondsTo: xxxClass)
('comparing' = closeTo: hash hashMappedBy: identityHashMappedBy: identityHashPrintString ~=)
('converting' adaptToFloat:andSend: adaptToFraction:andSend: adaptToInteger:andSend: as: asDraggableMorph asOrderedCollection asString complexContents mustBeBoolean printDirectlyToDisplay withoutListWrapper)
('copying' clone copy copyAddedStateFrom: copyFrom: copySameFrom: copyTwoLevel deepCopy initialDeepCopierSize shallowCopy veryDeepCopy veryDeepCopyWith: veryDeepCopyWithSiblingOf: veryDeepFixupWith: veryDeepInner: veryDeepPvtSibling:)
('dependents access' addDependent: breakDependents canDiscardEdits dependents evaluate:wheneverChangeIn: hasUnacceptedEdits myDependents myDependents: release removeDependent:)
('drag and drop' acceptDroppingMorph:event:inMorph: dragAnimationFor:transferMorph: dragPassengerFor:inMorph: dragTransferType dragTransferTypeForMorph: wantsDroppedMorph:event:inMorph:)
('error handling' assert: cannotInterpret: caseError confirm: confirm:orCancel: doesNotUnderstand: error: externalCallFailed halt halt: handles: notify: notify:at: notifyWithLabel: primitiveFailed shouldNotImplement subclassResponsibility tryToDefineVariableAccess:)
('events' myEvents myEvents: noEventsDo: removeAllEventsTriggered removeEvent: removeEventsTriggeredFor: trigger: trigger:with: trigger:withArguments: when:perform: when:send:to: when:send:to:with: when:send:to:withArguments: when:sendTo:)
('filter streaming' byteEncode: drawOnCanvas: elementSeparator encodePostscriptOn: flattenOnStream: fullDrawPostscriptOn: printOnStream: putOn: storeOnStream: writeOnFilterStream:)
('finalization' actAsExecutor executor finalize retryWithGC:until:)
('flagging' isThisEverCalled isThisEverCalled: logEntry logExecution logExit)
('logging' flag:log: flag:streamLog:)
('macpal' beep: codeStrippedOut: contentsChanged currentEvent currentHand currentVocabulary currentWorld flash ifKindOf:thenDo: instanceVariableValues isUniversalTiles objectRepresented playSoundNamed: refusesToAcceptCode scriptPerformer slotInfo)
('message handling' perform: perform:orSendTo: perform:with: perform:with:with: perform:with:with:with: perform:withArguments: perform:withArguments:inSuperclass:)
('objects from disk' comeFullyUpOnReload: convertToCurrentVersion:refStream: indexIfCompact objectForDataStream: readDataFrom:size: saveOnFile storeDataOn:)
('printing' fullPrintString isLiteral longPrintOn: longPrintOn:limitedTo:indent: longPrintString nominallyUnsent: printOn: printString printStringLimitedTo: propertyList reportableSize storeOn: storeString stringForReadout stringRepresentation)
('scripting' adaptedToWorld: contentsGetz: defaultFloatPrecisionFor: evaluateUnloggedForSelf: methodInterfacesForCategory:inVocabulary:limitClass: methodInterfacesForInstanceVariablesCategoryIn: methodInterfacesForScriptsCategoryIn: selfWrittenAsIll selfWrittenAsIm selfWrittenAsMe selfWrittenAsMy selfWrittenAsThis)
('system primitives' asOop becomeForward: className creationStamp instVarAt: instVarAt:put: instVarNamed: instVarNamed:put: oopString primitiveChangeClassTo: rootStubInImageSegment: someObject tryNamedPrimitive tryNamedPrimitive: tryNamedPrimitive:with: tryNamedPrimitive:with:with: tryNamedPrimitive:with:with:with: tryNamedPrimitive:with:with:with:with: tryNamedPrimitive:with:with:with:with:with: tryNamedPrimitive:with:with:with:with:with:with: tryNamedPrimitive:with:with:with:with:with:with:with: tryPrimitive:withArgs:)
('testing' basicType beViewed costumes haltIfNil haveFullProtocolBrowsed haveFullProtocolBrowsedShowingSelector: isBehavior isCollection isColor isFloat isForm isFraction isInteger isMorph isMorphicEvent isNumber isPoint isPseudoContext isStream isString isText isTransparent isVariableBinding isWebBrowser knownName name nameForViewer notNil openInstanceBrowserWithTiles renameTo: showDiffs stepAt:in: stepIn: stepTime stepTimeIn: vocabularyDemanded wantsDiffFeedback wantsSteps wantsStepsIn:)
('translation support' asIf:var: asIf:var:asValue: asIf:var:put: asOop: asSmallIntegerObj asValue: cCode: cCode:inSmalltalk: cCoerce:to: debugCode: export: inline: primitive:parameters:receiver: remapOop:in: returnTypeC: sharedCodeNamed:inCase: stAt: stAt:put: stSize static: suppressFailureGuards: var:declareC: var:type: var:type:array:)
('undo' capturedState commandHistory purgeAllCommands redoFromCapturedState: refineRedoTarget:selector:arguments:in: refineUndoTarget:selector:arguments:in: rememberCommand: rememberUndoableAction:named: undoFromCapturedState:)
('updating' changed changed: handledListVerification noteSelectionIndex:for: okToChange update: updateListsAndCodeIn: windowIsClosing)
('user interface' addModelItemsToWindowMenu: addModelMenuItemsTo:forMorph:hand: asExplorerString basicInspect beep browseHierarchy defaultBackgroundColor defaultLabelForInspector eToyStreamedRepresentationNotifying: explore fullScreenSize hasContentsInExplorer inform: initialExtent inspect inspectWithLabel: launchPartVia: launchPartVia:label: launchTileToRefer modelSleep modelWakeUp modelWakeUpIn: mouseUpBalk: newTileMorphRepresentative notYetImplemented windowActiveOnFirstClick windowReqNewLabel:)
('viewer' assureUniClass belongsToUniClass browseOwnClassSubProtocol categoriesForViewer: categoriesForVocabulary:limitClass: chooseNewNameForReference defaultLimitClassForVocabulary: defaultNameStemForInstances elementTypeFor:vocabulary: externalName graphicForViewerTab hasUserDefinedSlots infoFor:inViewer: initialTypeForSlotNamed: isPlayerLike methodInterfacesInPresentationOrderFrom:forCategory: newScriptorAround: offerViewerMenuFor:event: offerViewerMenuForEvt:morph: renameScript: tilePhrasesForCategory:inViewer: tileToRefer uniqueInstanceVariableNameLike:excluding: uniqueNameForReference uniqueNameForReferenceFrom: uniqueNameForReferenceOrNil updateThresholdForGraphicInViewerTab usableMethodInterfacesIn:)
('world hacking' couldOpenInMorphic)
('private' errorImproperStore errorNonIntegerIndex errorNotIndexable errorSubscriptBounds: primitiveError: species storeAt:inTempFrame:)
('scripts-kernel' universalTilesForGetterOf: universalTilesForInterface:)
('parts bin' descriptionForPartsBin)
('Camp Smalltalk' sunitAddDependent: sunitChanged: sunitRemoveDependent:)
('creation' asMorph openAsMorph)
('MIME' mimeType)
('*kom-processing' asHtmlDocumentForRequest: asHtmlElement asHtmlElementIn: asHttpResponseTo: comancheUrl makeAvailableInComanche)
!

