Object subclass: #SixxConstants
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxConstants class
	instanceVariableNames: 'xmlVersion xmlEncoding sixxVersion sixxStartTag xmlDeclaration '!

!SixxConstants class methodsFor: 'class initialization' stamp: 'MU 5/23/2002 17:29'!
initialize
	xmlVersion := nil.
	xmlEncoding := nil.
	sixxVersion := nil.
	sixxStartTag := nil.
	xmlDeclaration := nil! !


!SixxConstants class methodsFor: 'constants' stamp: 'MU 5/23/2002 17:30'!
sixxEndTag
	^ '</sixx>' copy! !

!SixxConstants class methodsFor: 'constants' stamp: 'MU 5/23/2002 17:27'!
sixxStartTag
	sixxStartTag isNil ifTrue: [sixxStartTag := '<sixx sixx.version="' , self sixxVersion , '">'].
	^sixxStartTag
		
! !

!SixxConstants class methodsFor: 'constants' stamp: 'MU 5/23/2002 17:24'!
xmlDeclaration
	xmlDeclaration isNil ifTrue: [xmlDeclaration := '<?xml version="', self xmlVersion, '" encoding="', self xmlEncoding, '"?>'].
	^xmlDeclaration
	! !


!SixxConstants class methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 17:59'!
sixxVersion
	sixxVersion isNil ifTrue: [sixxVersion := '1.0'].
	^sixxVersion! !

!SixxConstants class methodsFor: 'accessing' stamp: 'MU 5/23/2002 17:28'!
sixxVersion: versionString 
	sixxStartTag := nil.
	sixxVersion := versionString! !

!SixxConstants class methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 17:58'!
xmlEncoding
	xmlEncoding isNil ifTrue: [xmlEncoding := 'utf-8'].
	^ xmlEncoding! !

!SixxConstants class methodsFor: 'accessing' stamp: 'MU 5/23/2002 17:24'!
xmlEncoding: encodingString 
	xmlDeclaration := nil.
	xmlEncoding := encodingString! !

!SixxConstants class methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 17:57'!
xmlVersion
	xmlVersion isNil ifTrue: [xmlVersion := '1.0'].
	^ xmlVersion! !

!SixxConstants class methodsFor: 'accessing' stamp: 'MU 5/23/2002 17:24'!
xmlVersion: versionString 
	xmlDeclaration := nil.
	xmlVersion := versionString! !


Object subclass: #SixxReadStream
	instanceVariableNames: 'stream sixxElements contextDictionary position limit cachedObjects '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!
!SixxReadStream commentStamp: '<historical>' prior: 0!
I represent a ReadStream for SIXX format.

I can be used as follows:

srs := SixxReadStream readOnlyFileNamed: ('obj.sixx').
obj := srs next.
srs close.
obj inspect.

srs := SixxReadStream readOnlyFileNamed: ('objs.sixx').
objs := srs contents.
srs close.
objs inspect.

---
[:masashi | ^umezawa]!


!SixxReadStream methodsFor: 'initializing' stamp: 'kuri-t 5/31/2002 17:16'!
initialize
	contextDictionary := IdentityDictionary new.
	position := 0.
	sixxElements := self parseStream: stream.
	limit := sixxElements isNil
				ifTrue: [0]
				ifFalse: [sixxElements size].
	cachedObjects := Dictionary new! !

!SixxReadStream methodsFor: 'initializing' stamp: 'MU 5/31/2002 12:03'!
on: aStream 
	stream := aStream.
	self initialize! !

!SixxReadStream methodsFor: 'initializing' stamp: 'MU 6/11/2002 12:29'!
readOnlyFileNamed: fileName 
	stream := SixxPortableUtil readFileStreamNamed: fileName.
	self initialize! !


!SixxReadStream methodsFor: 'file open/close' stamp: 'MU 5/31/2002 12:09'!
close
	self stream close! !


!SixxReadStream methodsFor: 'reading' stamp: 'MU 6/7/2002 18:08'!
contents
	^(self next: self size) asArray! !

!SixxReadStream methodsFor: 'reading' stamp: 'kuri-t 5/31/2002 17:25'!
next
	^ self atEnd
		ifFalse: [position := position + 1. self cachedObjects
						at: position
						ifAbsentPut: [self
								readSixxFromSixxElement: (sixxElements at: position)]]! !

!SixxReadStream methodsFor: 'reading' stamp: 'MU 5/31/2002 12:29'!
next: anInteger 
	| ord |
	anInteger < 0 ifTrue: [^nil].
	ord := OrderedCollection new: anInteger.
	anInteger
		timesRepeat: [self atEnd
				ifFalse: [ord add: self next]].
	^ ord! !

!SixxReadStream methodsFor: 'reading' stamp: 'MU 5/31/2002 12:36'!
peek
	| nextObj |
	nextObj := self next.
	self privatePosition: self position - 1.
	^ nextObj! !

!SixxReadStream methodsFor: 'reading' stamp: 'kuri-t 5/21/2002 15:14'!
position
	^ position! !

!SixxReadStream methodsFor: 'reading' stamp: 'kuri-t 5/31/2002 16:32'!
position: anInteger 
	(anInteger < 0
			and: [anInteger > limit])
		ifTrue: [self error: 'out of bounds'].
	self reset.
	self next: anInteger! !

!SixxReadStream methodsFor: 'reading' stamp: 'MU 5/31/2002 12:36'!
reset
	self privatePosition: 0! !

!SixxReadStream methodsFor: 'reading' stamp: 'kuri-t 5/21/2002 11:54'!
size
	^ self limit! !

!SixxReadStream methodsFor: 'reading' stamp: 'kuri-t 5/31/2002 16:06'!
skip: anInteger
	self position: self position + anInteger.! !


!SixxReadStream methodsFor: 'testing' stamp: 'kuri-t 5/20/2002 18:54'!
atEnd
	^ self position >= self limit! !


!SixxReadStream methodsFor: 'accessing' stamp: 'kuri-t 5/31/2002 16:51'!
cachedObjects
	^ cachedObjects! !

!SixxReadStream methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 15:14'!
contextDictionary
	^ contextDictionary! !

!SixxReadStream methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 15:16'!
limit
	^ limit! !

!SixxReadStream methodsFor: 'accessing' stamp: 'kuri-t 5/21/2002 15:15'!
sixxElements
	^ sixxElements! !

!SixxReadStream methodsFor: 'accessing' stamp: 'kuri-t 5/17/2002 15:25'!
stream
	^ stream! !


!SixxReadStream methodsFor: 'private-accessing' stamp: 'MU 5/31/2002 14:45'!
privatePosition: anInteger 
	
	position := anInteger! !


!SixxReadStream methodsFor: 'private-recovery' stamp: 'MU 5/24/2003 18:39'!
findStringIndexes: subString from: sourceString 
	| foundIndexes index |
	foundIndexes := OrderedCollection new.
	index := 1.
	[index = 0]
		whileFalse: [index := sourceString findString: subString startingAt: index.
			index = 0
				ifFalse: [foundIndexes add: index.
					index := index + 1]].
	^ foundIndexes! !

!SixxReadStream methodsFor: 'private-recovery' stamp: 'MU 5/24/2003 19:05'!
recoveredStreamFrom: aStream 
	| contents startIndexes endIndexes recoverStream |
	contents := aStream contents.

	startIndexes := self findStringIndexes: '<sixx.object' from: contents.
	endIndexes := self findStringIndexes: '</sixx.object>' from: contents.

	recoverStream := ReadWriteStream with: (contents copyFrom: 1 to: (startIndexes last -1)).
	(startIndexes size - endIndexes size -1) timesRepeat: [recoverStream nextPutAll: '</sixx.object>'].
	recoverStream nextPutAll: '</sixx>'.

	^ recoverStream reset! !


!SixxReadStream methodsFor: 'private' stamp: 'kuri-t 5/21/2002 11:29'!
checkSixxElement: sixxElement 
	(SixxXmlUtil nameFrom: sixxElement)
			= 'sixx'
		ifFalse: [self error: 'unexpected element: '
					, (SixxXmlUtil nameFrom: sixxElement)]! !

!SixxReadStream methodsFor: 'private' stamp: 'MU 6/11/2003 17:23'!
parseStream: aStream 
	| root str recoverTried |
	(aStream isNil or: [aStream size = 0])	ifTrue: [^nil].
	str := aStream.
	recoverTried := false.
	[root := SixxXmlUtil parseXml: str]
		on: SixxXmlParseError do: [:ex | (SixxSetting useRecoveryRead and: [recoverTried not])
			ifTrue: 
				[str := self recoveredStreamFrom: str.
				recoverTried := true.
				ex retry]
			ifFalse: [ex pass]].
	self checkSixxElement: root.
	^SixxXmlUtil elementsFrom: root! !

!SixxReadStream methodsFor: 'private' stamp: 'kuri-t 5/20/2002 16:51'!
readSixxFromSixxElement: sixxElement 
	^ Object readSixxFromSixxElement: sixxElement context: self contextDictionary! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxReadStream class
	instanceVariableNames: ''!

!SixxReadStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/21/2002 15:23'!
new
	self error: 'Streams are created with on:'! !

!SixxReadStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/31/2002 16:42'!
on: readStream 
	^ self basicNew on: readStream! !

!SixxReadStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/21/2002 15:22'!
readOnlyFileNamed: fileName 
	^ self basicNew readOnlyFileNamed: fileName! !


Object subclass: #SixxSetting
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxSetting class
	instanceVariableNames: 'useCDATA useEnvironment useRecoveryRead '!

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 9/2/2002 02:26'!
useCDATA
	useCDATA isNil ifTrue: [useCDATA := false].
	^useCDATA! !

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 9/2/2002 02:26'!
useCDATA: aBoolean
	useCDATA := aBoolean! !

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 3/6/2003 12:55'!
useEnvironment
	useEnvironment isNil ifTrue: [useEnvironment := false].
	^useEnvironment! !

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 3/6/2003 12:55'!
useEnvironment: aBoolean
	useEnvironment := aBoolean! !

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 5/24/2003 18:32'!
useRecoveryRead
	useRecoveryRead isNil ifTrue: [useRecoveryRead := false].
	^useRecoveryRead! !

!SixxSetting class methodsFor: 'accessing' stamp: 'MU 5/24/2003 18:33'!
useRecoveryRead: aBoolean
	useRecoveryRead := aBoolean! !


Warning subclass: #SixxWarning
	instanceVariableNames: 'className element context '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

!SixxWarning methodsFor: 'exceptionDescription' stamp: 'MU 10/26/2002 01:35'!
defaultAction
	Transcript cr; show: '#warning# ' , self description.
	self resume! !


!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
className

	^className! !

!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
className: aValue

	className := aValue! !

!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
context

	^context! !

!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
context: aValue

	context := aValue! !

!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
element
	^ element! !

!SixxWarning methodsFor: 'accessing' stamp: 'MU 10/26/2002 01:35'!
element: aValue 
	element := aValue! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxWarning class
	instanceVariableNames: ''!

!SixxWarning class methodsFor: 'instance creation' stamp: 'MU 10/27/2002 17:23'!
signal: className
	^self signal: className context: nil ! !

!SixxWarning class methodsFor: 'instance creation' stamp: 'MU 10/27/2002 17:23'!
signal: className context: dictionary 
	^self signal: className element: nil context: dictionary ! !

!SixxWarning class methodsFor: 'instance creation' stamp: 'MU 10/27/2002 17:27'!
signal: className element: xmlElement 
	^self signal: className element: xmlElement context: nil ! !

!SixxWarning class methodsFor: 'instance creation' stamp: 'MU 10/26/2002 01:35'!
signal: className element: xmlElement context: dictionary 
	| inst |
	inst := self new.
	inst className: className.
	inst element: xmlElement.
	inst context: dictionary.
	^ inst signal! !


SixxWarning subclass: #SixxClassNotFound
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

!SixxClassNotFound methodsFor: 'exceptionDescription' stamp: 'MU 10/27/2002 19:39'!
description
	"Return a textual description of the exception."
	self className isNil ifTrue: [ ^super description , ': ', 'Type cannot be detected from XML'].
	^ super description , ': ' , self className! !


SixxWarning subclass: #SixxInvalidDeserialization
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

!SixxInvalidDeserialization methodsFor: 'exceptionDescription' stamp: 'MU 10/27/2002 19:50'!
description
	"Return a textual description of the exception."
	^ super description , ': ' , self className printString! !


SixxWarning subclass: #SixxInvalidSerialization
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

!SixxInvalidSerialization methodsFor: 'exceptionDescription' stamp: 'MU 10/27/2002 19:50'!
description
	"Return a textual description of the exception."
	^ super description , ': ' , self className printString! !


Object subclass: #SixxWriteStream
	instanceVariableNames: 'stream contextDictionary isStartTagPut isEndTagPut '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!
!SixxWriteStream commentStamp: '<historical>' prior: 0!
I represent a WriteStream for SIXX format.

I can be used as follows:

srs := SixxWriteStream newFileNamed: ('obj.sixx').
srs nextPut: <object>.
srs close.

srs := SixxWriteStream newFileNamed: ('objs.sixx').
srs nextPutAll: <collection of object>.
srs close.

---
[:masashi | ^umezawa]!


!SixxWriteStream methodsFor: 'initializing' stamp: 'MU 5/31/2002 11:34'!
initialize
	contextDictionary := IdentityDictionary new.
	isStartTagPut := false.
	isEndTagPut := false. 
	! !

!SixxWriteStream methodsFor: 'initializing' stamp: 'MU 6/14/2002 11:59'!
newFileNamed: fileName 
	stream := SixxPortableUtil writeFileStreamNamed: fileName.
	self initialize! !

!SixxWriteStream methodsFor: 'initializing' stamp: 'MU 5/31/2002 11:19'!
on: aStream
	stream := aStream.
	! !


!SixxWriteStream methodsFor: 'file open/close' stamp: 'MU 5/31/2002 11:45'!
close
	self endTag.
	self stream close
! !


!SixxWriteStream methodsFor: 'actions' stamp: 'MU 5/31/2002 11:53'!
rawContents
	^self stream contents
! !


!SixxWriteStream methodsFor: 'writing' stamp: 'kuri-t 5/17/2002 13:56'!
cr
	self stream cr! !

!SixxWriteStream methodsFor: 'writing' stamp: 'MU 5/31/2002 12:00'!
endTag
	(self isStartTagPut and: [ self isEndTagPut not] )
		ifTrue: [self stream nextPutAll: SixxConstants sixxEndTag.
			self isEndTagPut: true]! !

!SixxWriteStream methodsFor: 'writing' stamp: 'MU 5/31/2002 11:45'!
nextPut: anObject 
	self startTag.
	anObject
		sixxOn: self stream
		indent: 1
		context: self contextDictionary! !

!SixxWriteStream methodsFor: 'writing' stamp: 'kuri-t 5/17/2002 14:31'!
nextPutAll: aCollection 
	aCollection
		do: [:obj | self nextPut: obj]! !

!SixxWriteStream methodsFor: 'writing' stamp: 'MU 5/31/2002 11:52'!
startTag
	self isStartTagPut
		ifFalse: [self stream nextPutAll: SixxConstants sixxStartTag.
			self isStartTagPut: true.
			self cr]! !

!SixxWriteStream methodsFor: 'writing' stamp: 'MU 5/31/2002 11:48'!
xmlDeclaration
	self stream nextPutAll: SixxConstants xmlDeclaration; cr! !


!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
contextDictionary

	^contextDictionary! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
contextDictionary: aValue

	contextDictionary := aValue! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
isEndTagPut

	^isEndTagPut! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
isEndTagPut: aValue

	isEndTagPut := aValue! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
isStartTagPut

	^isStartTagPut! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
isStartTagPut: aValue

	isStartTagPut := aValue! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
stream

	^stream! !

!SixxWriteStream methodsFor: 'accessing' stamp: 'MU 5/31/2002 11:35'!
stream: aValue

	stream := aValue! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxWriteStream class
	instanceVariableNames: ''!

!SixxWriteStream class methodsFor: 'instance creation' stamp: 'MU 5/31/2002 11:20'!
new
	^super new initialize! !

!SixxWriteStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/17/2002 12:29'!
newFileNamed: fileName 
	^ self new newFileNamed: fileName! !

!SixxWriteStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/31/2002 16:42'!
on: writeStream 
	^ self new on: writeStream! !

!SixxWriteStream class methodsFor: 'instance creation' stamp: 'kuri-t 5/31/2002 16:42'!
onWithDeclaration: writeStream 
	^ (self on: writeStream) xmlDeclaration! !


Error subclass: #SixxXmlParseError
	instanceVariableNames: 'originalError '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

!SixxXmlParseError methodsFor: 'accessing' stamp: 'MU 5/24/2003 18:59'!
originalError
	^originalError! !

!SixxXmlParseError methodsFor: 'accessing' stamp: 'MU 5/24/2003 18:59'!
originalError: anError
	originalError := anError! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxXmlParseError class
	instanceVariableNames: ''!

!SixxXmlParseError class methodsFor: 'instance creation' stamp: 'MU 5/24/2003 19:00'!
originalError: anError
	^self new originalError: anError! !


Object subclass: #SixxXmlUtil
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SIXX-Core'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SixxXmlUtil class
	instanceVariableNames: 'convertCharDict parserAdapter '!

!SixxXmlUtil class methodsFor: 'class initialization' stamp: 'kuri-t 5/16/2002 12:03'!
initialize
	"SixxXmlUtil initialize"
	self initConvertCharDict.
	parserAdapter := nil! !


!SixxXmlUtil class methodsFor: 'actions' stamp: 'MU 4/19/2002 18:03'!
asXmlText: aString 
	|  wStr |
	wStr := WriteStream
				on: (String new: aString size).
	^(self writeXmlText: aString on: wStr) contents! !

!SixxXmlUtil class methodsFor: 'actions' stamp: 'MU 4/19/2002 18:08'!
contentsWithXmlDeclaration: aString 
	| wStr |
	wStr := WriteStream
				on: (String new: 1024).
	wStr nextPutAll: self xmlDeclaration.
	2
		timesRepeat: [wStr nextPut: Character cr.
			wStr nextPut: Character lf].
	wStr nextPutAll: aString.
	^ wStr contents! !

!SixxXmlUtil class methodsFor: 'actions' stamp: 'MU 6/11/2003 17:24'!
parseXml: xmlStringOrStream 
	^[self parserAdapter parseXml: xmlStringOrStream] on: Error
		do: [:ex | SixxPortableUtil signalException: (SixxXmlParseError originalError: ex)]! !

!SixxXmlUtil class methodsFor: 'actions' stamp: 'MU 9/2/2002 02:24'!
writeXmlText: aString on: aWriteStream 
	SixxSetting useCDATA
		ifTrue: [aWriteStream nextPutAll: '<!![CDATA['.
			aWriteStream nextPutAll: aString.
			aWriteStream nextPutAll: ']]>']
		ifFalse: [self convertWriteXmlText: aString on: aWriteStream]! !


!SixxXmlUtil class methodsFor: 'actions-parse' stamp: 'kuri-t 5/16/2002 12:12'!
attributeAt: attributeName from: sixxElement 
	^ self parserAdapter attributeAt: attributeName from: sixxElement! !

!SixxXmlUtil class methodsFor: 'actions-parse' stamp: 'kuri-t 5/16/2002 12:12'!
characterDataFrom: sixxElement
	^ self parserAdapter characterDataFrom: sixxElement! !

!SixxXmlUtil class methodsFor: 'actions-parse' stamp: 'kuri-t 5/16/2002 12:12'!
elementsFrom: sixxElement
	^ self parserAdapter elementsFrom: sixxElement! !

!SixxXmlUtil class methodsFor: 'actions-parse' stamp: 'kuri-t 5/16/2002 12:12'!
isTextFrom: sixxElement
	^ self parserAdapter isTextFrom: sixxElement! !

!SixxXmlUtil class methodsFor: 'actions-parse' stamp: 'kuri-t 5/20/2002 14:53'!
nameFrom: sixxElement 
	^ self parserAdapter nameFrom: sixxElement! !


!SixxXmlUtil class methodsFor: 'accessing' stamp: 'MU 4/19/2002 18:03'!
convertCharDict
	^convertCharDict! !

!SixxXmlUtil class methodsFor: 'accessing' stamp: 'kuri-t 5/16/2002 12:09'!
parserAdapter
	parserAdapter isNil
		ifTrue: [parserAdapter := (self environment includesKey: #XMLDOMParser)
						ifTrue: [self environment at: #SixxYaxoXmlParserAdapter]
						ifFalse: [(self environment includesKey: #VWXMLXMLParser)
								ifTrue: [self environment at: #SixxVwXmlParserAdapter]]].
	^ parserAdapter! !

!SixxXmlUtil class methodsFor: 'accessing' stamp: 'kuri-t 5/16/2002 12:10'!
parserAdapter: aSixxXmlParserAdapter 
	parserAdapter := aSixxXmlParserAdapter! !


!SixxXmlUtil class methodsFor: 'private-initialize' stamp: 'MU 9/2/2002 02:44'!
convertWriteXmlText: aString on: aWriteStream
	| cDict wStr |
	cDict := self convertCharDict.
	wStr := aWriteStream.
	aString
		do: [:eachChar | 
			| val | 
			val := eachChar asciiValue.
			val >= 127
				ifTrue: [wStr nextPutAll: '&#';
						 nextPutAll: val printString;
						 nextPut: $;]
				ifFalse: [| conv | 
					conv := cDict
								at: val
								ifAbsent: [].
					conv isNil
						ifTrue: [wStr nextPut: eachChar]
						ifFalse: [wStr nextPutAll: conv]]].
	^wStr! !

!SixxXmlUtil class methodsFor: 'private-initialize' stamp: 'MU 9/2/2002 02:07'!
initConvertCharDict
	convertCharDict := Dictionary new.
	0 to: 47 do: [:each | convertCharDict at: each put: '&#', each asString, ';'].
	convertCharDict 
		at: $& asciiValue put: '&amp;';
		at: $< asciiValue put: '&lt;';
		at: $> asciiValue put: '&gt;';
		at: $' asciiValue put: '&apos;';
		at: $" asciiValue put: '&quot;'.
	convertCharDict 
		removeKey: Character space asciiValue;
		removeKey: Character tab asciiValue;
		removeKey: Character cr asciiValue;
		removeKey: Character lf asciiValue.
	convertCharDict 
		removeKey: $/ asciiValue;
		removeKey: $- asciiValue;
		removeKey: $. asciiValue.! !

SixxConstants initialize!
SixxXmlUtil initialize!